==> pmml-model-1.4.15-sources.jar: org/dmg/pmml/neural_network/PMMLAttributes.java <==

package org.dmg.pmml.neural_network;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field CONNECTION_FROM = org.jpmml.model.ReflectionUtil.getField(Connection.class, "from");
    Field CONNECTION_WEIGHT = org.jpmml.model.ReflectionUtil.getField(Connection.class, "weight");
    Field NEURALINPUT_ID = org.jpmml.model.ReflectionUtil.getField(NeuralInput.class, "id");
    Field NEURALINPUTS_NUMBEROFINPUTS = org.jpmml.model.ReflectionUtil.getField(NeuralInputs.class, "numberOfInputs");
    Field NEURALLAYER_NUMBEROFNEURONS = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "numberOfNeurons");
    Field NEURALLAYER_ACTIVATIONFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "activationFunction");
    Field NEURALLAYER_THRESHOLD = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "threshold");
    Field NEURALLAYER_WIDTH = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "width");
    Field NEURALLAYER_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "altitude");
    Field NEURALLAYER_NORMALIZATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "normalizationMethod");
    Field NEURALNETWORK_MODELNAME = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "modelName");
    Field NEURALNETWORK_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "miningFunction");
    Field NEURALNETWORK_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "algorithmName");
    Field NEURALNETWORK_ACTIVATIONFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "activationFunction");
    Field NEURALNETWORK_NORMALIZATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "normalizationMethod");
    Field NEURALNETWORK_THRESHOLD = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "threshold");
    Field NEURALNETWORK_WIDTH = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "width");
    Field NEURALNETWORK_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "altitude");
    Field NEURALNETWORK_NUMBEROFLAYERS = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "numberOfLayers");
    Field NEURALNETWORK_SCORABLE = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "scorable");
    Field NEURALNETWORK_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "mathContext");
    Field NEURALOUTPUT_OUTPUTNEURON = org.jpmml.model.ReflectionUtil.getField(NeuralOutput.class, "outputNeuron");
    Field NEURALOUTPUTS_NUMBEROFOUTPUTS = org.jpmml.model.ReflectionUtil.getField(NeuralOutputs.class, "numberOfOutputs");
    Field NEURON_ID = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "id");
    Field NEURON_BIAS = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "bias");
    Field NEURON_WIDTH = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "width");
    Field NEURON_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "altitude");

}

==> pmml-model-1.5.16-sources.jar: org/dmg/pmml/neural_network/PMMLAttributes.java <==

package org.dmg.pmml.neural_network;

import java.lang.reflect.Field;

public interface PMMLAttributes {

    Field CONNECTION_FROM = org.jpmml.model.ReflectionUtil.getField(Connection.class, "from");
    Field CONNECTION_WEIGHT = org.jpmml.model.ReflectionUtil.getField(Connection.class, "weight");
    Field NEURALINPUT_ID = org.jpmml.model.ReflectionUtil.getField(NeuralInput.class, "id");
    Field NEURALINPUTS_NUMBEROFINPUTS = org.jpmml.model.ReflectionUtil.getField(NeuralInputs.class, "numberOfInputs");
    Field NEURALLAYER_NUMBEROFNEURONS = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "numberOfNeurons");
    Field NEURALLAYER_ACTIVATIONFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "activationFunction");
    Field NEURALLAYER_THRESHOLD = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "threshold");
    Field NEURALLAYER_LEAKAGE = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "leakage");
    Field NEURALLAYER_WIDTH = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "width");
    Field NEURALLAYER_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "altitude");
    Field NEURALLAYER_NORMALIZATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(NeuralLayer.class, "normalizationMethod");
    Field NEURALNETWORK_MODELNAME = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "modelName");
    Field NEURALNETWORK_MININGFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "miningFunction");
    Field NEURALNETWORK_ALGORITHMNAME = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "algorithmName");
    Field NEURALNETWORK_ACTIVATIONFUNCTION = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "activationFunction");
    Field NEURALNETWORK_NORMALIZATIONMETHOD = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "normalizationMethod");
    Field NEURALNETWORK_THRESHOLD = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "threshold");
    Field NEURALNETWORK_LEAKAGE = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "leakage");
    Field NEURALNETWORK_WIDTH = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "width");
    Field NEURALNETWORK_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "altitude");
    Field NEURALNETWORK_NUMBEROFLAYERS = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "numberOfLayers");
    Field NEURALNETWORK_SCORABLE = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "scorable");
    Field NEURALNETWORK_MATHCONTEXT = org.jpmml.model.ReflectionUtil.getField(NeuralNetwork.class, "mathContext");
    Field NEURALOUTPUT_OUTPUTNEURON = org.jpmml.model.ReflectionUtil.getField(NeuralOutput.class, "outputNeuron");
    Field NEURALOUTPUTS_NUMBEROFOUTPUTS = org.jpmml.model.ReflectionUtil.getField(NeuralOutputs.class, "numberOfOutputs");
    Field NEURON_ID = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "id");
    Field NEURON_BIAS = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "bias");
    Field NEURON_WIDTH = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "width");
    Field NEURON_ALTITUDE = org.jpmml.model.ReflectionUtil.getField(Neuron.class, "altitude");

}
